@@ -1,4 +1,4 @@
-# Copyright (c) 2015-2019 Patricio Cubillos and contributors.
+# Copyright (c) 2015-2021 Patricio Cubillos and contributors.
 # MC3 is open-source software under the MIT license (see LICENSE).
 
 __all__ = ["mcmc"]
@@ -241,7 +241,7 @@ def mcmc(data, uncert, func, params, indparams, pmin, pmax, pstep,
       best_log_post.value = log_post[izbest]
       bestp[ifree] = np.copy(Z[izbest])
       if fit_output is not None:
-          bestp = np.copy(fit_output['bestp'])
+          bestp[:] = np.copy(fit_output['bestp'])
           best_log_post.value = fit_output['best_log_post']
 
   # ::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
