@@ -1,4 +1,4 @@
-# Copyright (c) 2015-2019 Patricio Cubillos and contributors.
+# Copyright (c) 2015-2021 Patricio Cubillos and contributors.
 # MC3 is open-source software under the MIT license (see LICENSE).
 
 __all__ = [
@@ -25,10 +25,6 @@ import mc3.utils as mu
 import mc3.stats as ms
 
 
-if sys.version_info.major == 2:
-    range = xrange
-
-
 # Color themes for histogram plots:
 themes = {
     'blue':{
@@ -168,8 +164,7 @@ def histogram(posterior, pnames=None, thinning=1, fignum=1100,
               savefile=None, bestp=None, quantile=None, pdf=None,
               xpdf=None, ranges=None, axes=None, lw=2.0, fs=11,
               theme='blue', yscale=False, orientation='vertical',
-              # Deprecated: Remove by 2020-07-01
-              percentile=None):
+              ):
   """
   Plot parameter marginal posterior distributions
 
