@@ -1,15 +1,16 @@
-# Copyright (c) 2015-2019 Patricio Cubillos and contributors.
+# Copyright (c) 2015-2021 Patricio Cubillos and contributors.
 # MC3 is open-source software under the MIT license (see LICENSE).
 
 from .gelman import *
 from .stats import *
 from .time_averaging import *
-
+from .prayer import *
 
 __all__ = (
     gelman.__all__
   + stats.__all__
   + time_averaging.__all__
+  + prayer.__all__
     )
 
 
